@@ -15,7 +15,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = ["Samuel Stauffer"]
 __license__ = "GPL"
-__version__ = "0.9.14"
+__version__ = "0.9.15"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -282,9 +282,9 @@ class MuninPlugin:
         @return:     Return True if the attribute is enabled.
         
         """
-        filter = self._filters.get(name)
-        if filter:
-            return filter.check(attr) 
+        flt = self._filters.get(name)
+        if flt:
+            return flt.check(attr) 
         else:
             raise AttributeError("Undefined filter: %s" % name)
         
@@ -669,15 +669,17 @@ class MuninGraph:
                              by replacing them with '_'.
         
         """
-        self._graphAttrDict = locals()
+        self._graphAttrDict = dict((k,v) for (k,v) in locals().iteritems()
+                                    if (v is not None 
+                                        and k not in ('self', 'autoFixNames')))
         self._fieldNameList = []
         self._fieldAttrDict = {}
         self._fieldValDict = {}
         self._autoFixNames = autoFixNames
 
-    def addField(self, name, label, type=None,  draw=None, info=None, 
+    def addField(self, name, label, type=None,  draw=None, info=None, #@ReservedAssignment
                  extinfo=None, colour=None, negative=None, graph=None, 
-                 min=None, max=None, cdef=None, line=None, 
+                 min=None, max=None, cdef=None, line=None, #@ReservedAssignment
                  warning=None, critical=None):
         """Add field to Munin Graph
         
@@ -705,7 +707,9 @@ class MuninGraph:
             name = self._fixName(name)
             if negative is not None:
                 negative = self._fixName(negative)
-        self._fieldAttrDict[name] = locals()
+        self._fieldAttrDict[name] = dict(((k,v) for (k,v) in locals().iteritems()
+                                         if (v is not None
+                                             and k not in ('self',))))
         self._fieldNameList.append(name)
 
     def hasField(self, name):
