@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """tomcatstats - Munin Plugin to monitor Apache Tomcat Application Server.
 
 Requirements
@@ -43,8 +43,8 @@ Environment Variables
 
 """
 # Munin  - Magic Markers
-#%# family=manual
-#%# capabilities=noautoconf nosuggest
+#%# family=auto
+#%# capabilities=autoconf nosuggest
 
 import sys
 from pymunin import MuninGraph, MuninPlugin, muninMain
@@ -80,7 +80,7 @@ class MuninTomcatPlugin(MuninPlugin):
         self.envRegisterFilter('ports', '^\d+$')
         
         self._host = self.envGet('host')
-        self._port = self.envGet('port')
+        self._port = self.envGet('port', None, int)
         self._user = self.envGet('user')
         self._password = self.envGet('password')
         self._ssl = self.envCheckFlag('ssl', False)
@@ -214,6 +214,14 @@ class MuninTomcatPlugin(MuninPlugin):
             
         """
         return self.envCheckFilter('ports', str(port))
+    
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        return self._tomcatInfo is not None
 
 
 def main():
